==> tine20-allinone_2020.08.8.tar.bz2: Tasks/js/Tasks-lang-sq-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: sq\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""

]
, "Task, Tasks"
: [
  "Detyrë"
 ,"Detyra"

]
, "Percent"
: "Përqind"

, "Completed"
: "Përfunduar"

, "Due"
: "Caktuar"

, "Class"
: ""

, "Description"
: "Përshkrimi"

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: "Organizues"

, "Priority"
: "Prioriteti"

, "Status, Status"
: [
  "Status"
 ,"Statuse"

]
, "Lead"
: "Drejtim"

, "Telephone"
: "Telefon"

, "Email"
: "E-Postë"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Ju duhet të caktoni një datë, pasi është vënë një alarm!"

, "Summary"
: "Përmbledhje"

, "Due date"
: "Data e caktuar"

, "Add Responsible ..."
: "Shto Përgjegjës..."

, "Notes"
: "Shënime"

, "Enter description..."
: "Vendos përshkrim..."

, "Percentage"
: "Përqindje"

, "Tasks"
: "Detyra"

, "to do list, to do lists"
: [
  "Listë Për Tu Bërë"
 ,"Lista Për Tu Bërë"

]
, "to do lists"
: "lista Për Tu Bërë"

, "Quick Search"
: "Kërkim i Shpejtë"

, "Due Date"
: "Data e caktuar"

, "Responsible"
: "Përgjegjës"

, "Last Modified Time"
: "Koha e Modifikimt të fundit"

, "Last Modified By"
: "Modifikimi i fundit nga "

, "Creation Time"
: "Koha e Krijimit"

, "Created By"
: "Krijuar nga"

, "New Task"
: "Detyrë e re"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Doni vërtetë të fshini detyrën e zgjedhur?"
 ,"Doni vërtetë të fshini detyrat e zgjedhura?"

]
, "Attachments"
: ""

, "Tags"
: "Etiketa"

, "Lead name"
: ""

, "Add a task..."
: "Shto një detyrë..."

, "All my tasks"
: "Të gjithë detyrat e mia"

, "Default Favorite"
: "Preferencialet e paracaktuara"

, "The default favorite which is loaded on Tasks startup"
: "Preferencialia e paracaktuar që ngarkohet kur nisin Detyrat"

, "Default Task List"
: "Lista e paracaktuar e detyrave"

, "The default task list to create new tasks in."
: "Lista e paracaktuar e detyrave ku të krijohen detyrat e reja"

, "Tasks status available"
: "Status detyre i disponueshëm"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Status detyre i mudshëm. Kujdes, pasi status tjetër vijuesi mund të ndikoje sisteme të tjerë Detyrashgjatë eksportimit ose sinkronizimit"

, "No response"
: "Nuk ka përgjigje"

, "Cancelled"
: "Anulluar"

, "In process"
: "Në procesim"

, "Task priorities available"
: "Prioritete detyrash të disponueshme"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Prioritete detyrash të mundshme. Kujdes, pasi prijoritete të tjerë mund të kenë ndikim në sisteme të tjerë Detyrashgjatë eksportimit ose sinkronizimit"

, "low"
: "ulët"

, "normal"
: "normal"

, "high"
: "lartë"

, "urgent"
: "urgjent"

, "manage shared task lists"
: "menaxho listat e detyrave të ndara"

, "Create new shared tasks lists"
: "Rrijo një listë detyrash të ndara të re "

, "manage shared tasks favorites"
: "Menaxho preferencialet e detyrave të ndara"

, "Create or update shared tasks favorites"
: "Krijo ose përditëso preferenciale të detyrave të ndara"

, "%s's personal tasks"
: "Detyra personale e %s"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Gjithë detyrat e listës time të detyrave"

, "My open tasks"
: "Detyrat e mia të hapura"

, "My open tasks this week"
: "Detyrat e mia të hapura të kësaj jave"

, "All tasks for me"
: "Gjithë detyrat për mua"

, "All tasks that I am responsible for"
: "Gjithë detyrat për të cilat jam përgjegjës"

, "Last modified by me"
: "Modifikimi i fundit nga unë"

, "All tasks that I have last modified"
: "Gjithë detyrat e fundit të modifikuara nga unë"

, "Tasks without responsible"
: "Detyra pa përgjegjës"

, "GENDER_Task"
: ""

, "Task"
: "Detyrë"

, "Status"
: "Status"

, "to do list"
: "Listë Për Tu Bërë"

, "Do you really want to delete the selected task?"
: "Doni vërtetë të fshini detyrën e zgjedhur?"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-sq-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Ju duhet të caktoni një datë, pasi është vënë një alarm!"

, "Summary"
: "Përmbledhje"

, "Due date"
: "Data e caktuar"

, "Priority"
: "Prioriteti"

, "Organizer"
: "Organizues"

, "Add Responsible ..."
: "Shto Përgjegjës..."

, "Notes"
: "Shënime"

, "Enter description..."
: "Vendos përshkrim..."

, "Percentage"
: "Përqindje"

, "Status, Status"
: [
  "Status"
 ,"Statuse"

]
, "Completed"
: "Përfunduar"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Doni vërtetë të fshini detyrën e zgjedhur?"
 ,"Doni vërtetë të fshini detyrat e zgjedhura?"

]
, "Attachments"
: ""

, "Tags"
: "Etiketa"

, "Lead name"
: ""

, "Add a task..."
: "Shto një detyrë..."

, "Due Date"
: "Data e caktuar"

, "Percent"
: "Përqind"

, "Responsible"
: "Përgjegjës"

, "Task, Tasks"
: [
  "Detyrë"
 ,"Detyra"

]
, "Tasks"
: "Detyra"

, "to do list, to do lists"
: [
  "Listë Për Tu Bërë"
 ,"Lista Për Tu Bërë"

]
, "to do lists"
: "lista Për Tu Bërë"

, "Quick Search"
: "Kërkim i Shpejtë"

, "Last Modified Time"
: "Koha e Modifikimt të fundit"

, "Last Modified By"
: "Modifikimi i fundit nga "

, "Creation Time"
: "Koha e Krijimit"

, "Created By"
: "Krijuar nga"

, "New Task"
: "Detyrë e re"

, "All my tasks"
: "Të gjithë detyrat e mia"

, "Default Favorite"
: "Preferencialet e paracaktuara"

, "The default favorite which is loaded on Tasks startup"
: "Preferencialia e paracaktuar që ngarkohet kur nisin Detyrat"

, "Default Task List"
: "Lista e paracaktuar e detyrave"

, "The default task list to create new tasks in."
: "Lista e paracaktuar e detyrave ku të krijohen detyrat e reja"

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: "Status detyre i disponueshëm"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Status detyre i mudshëm. Kujdes, pasi status tjetër vijuesi mund të ndikoje sisteme të tjerë Detyrashgjatë eksportimit ose sinkronizimit"

, "No response"
: "Nuk ka përgjigje"

, "Cancelled"
: "Anulluar"

, "In process"
: "Në procesim"

, "Task priorities available"
: "Prioritete detyrash të disponueshme"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Prioritete detyrash të mundshme. Kujdes, pasi prijoritete të tjerë mund të kenë ndikim në sisteme të tjerë Detyrashgjatë eksportimit ose sinkronizimit"

, "low"
: "ulët"

, "normal"
: "normal"

, "high"
: "lartë"

, "urgent"
: "urgjent"

, "%s's personal tasks"
: "Detyra personale e %s"

, "GENDER_Task"
: ""

, "Due"
: "Caktuar"

, "Class"
: ""

, "Description"
: "Përshkrimi"

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: "Drejtim"

, "Telephone"
: "Telefon"

, "Email"
: "E-Postë"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Gjithë detyrat e listës time të detyrave"

, "My open tasks"
: "Detyrat e mia të hapura"

, "My open tasks this week"
: "Detyrat e mia të hapura të kësaj jave"

, "All tasks for me"
: "Gjithë detyrat për mua"

, "All tasks that I am responsible for"
: "Gjithë detyrat për të cilat jam përgjegjës"

, "Last modified by me"
: "Modifikimi i fundit nga unë"

, "All tasks that I have last modified"
: "Gjithë detyrat e fundit të modifikuara nga unë"

, "Tasks without responsible"
: "Detyra pa përgjegjës"

, "manage shared task lists"
: "menaxho listat e detyrave të ndara"

, "Create new shared tasks lists"
: "Rrijo një listë detyrash të ndara të re "

, "manage shared tasks favorites"
: "Menaxho preferencialet e detyrave të ndara"

, "Create or update shared tasks favorites"
: "Krijo ose përditëso preferenciale të detyrave të ndara"

, "Status"
: "Status"

, "Do you really want to delete the selected task?"
: "Doni vërtetë të fshini detyrën e zgjedhur?"

, "Task"
: "Detyrë"

, "to do list"
: "Listë Për Tu Bërë"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
